@@ -11,7 +11,7 @@ class ObjectPermissionBackend(object):
     supports_anonymous_user = True
     supports_inactive_user = True
 
-    def authenticate(self, username, password):
+    def authenticate(self, username, password): # pragma: no cover
         return None
 
     def has_perm(self, user_obj, perm, obj=None):
